@@ -55,7 +55,7 @@ be created for the lifetime of the spawner.
 use strict;
 use warnings;
 
-our $VERSION = '2.16';
+our $VERSION = '2.17';
 
 use Carp qw/ croak /;
 use Danga::Socket ();
@@ -148,7 +148,7 @@ sub new {
     $gearmand_spec = $params{gearmand};
     gearman_servers(); # init the server singleton if necessary
 
-    croak 'gearmand location not specified' unless defined @{ gearman_servers() };
+    croak 'gearmand location not specified' unless @{ gearman_servers() };
 
     # NB: this structure must be Storable-serializable for all bits used by
     # _supervise. see special handling in add_worker
